from Kuyil.entity.repository_entity import RepositoryEntity


class Kuyil:

    @staticmethod
    def get_repository(name):
        print("Hi")

    @staticmethod
    def create_dataset(dataset_class, instance, label, repository, comment=None,
                       metadata=None,only_create=False):
        print()

