class Repository():

    def init(self):
        print()

    def maintain_write_lock(self, pid):
        print()

    def write_failed(self, pid, comment=None):
        print()

    def write_success(self, pid, comment=None):
        print()